<?php

/**
 * @package     EasyStore.Site
 * @subpackage  EasyStore.Sample
 *
 * @copyright   Copyright (C) 2023 JoomShaper <https://www.joomshaper.com>. All rights reserved.
 * @license     GNU General Public License version 3; see LICENSE
 */

namespace JoomShaper\Plugin\EasyStore\Sample\Utils;

use Joomla\Registry\Registry;
use JoomShaper\Component\EasyStore\Administrator\Plugin\Constants;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * Class that contains constants for the Paddle payment gateway.
 * @since 1.0.0
 */
class SampleConstants extends Constants
{
    /**
     * Plugin parameters
     *
     * @var Registry
     * 
     * @since 1.0.0
     */
    protected $params;

    /**
     * The payment plugin name
     *
     * @var string
     * 
     * @since 1.0.0
     */
    protected $name = 'sample';

    /**
     * Constant values for payment settings.
     */
    const TEST_URL = 'https://www.test/url';
    const LIVE_URL = 'https://www.live/url';

    /**
     * The constructor method.
     * 
     * @since 1.0.0
     */
    public function __construct()
    {    
        /* By passing the plugin name as a parameter to the parent constructor, both plugin information and parameters will be retrieved . */
        
        parent::__construct($this->name);
    }


    /**
     * Get Test Merchant Key
     *
     * @return string
     * 
     * @since 1.0.0
     */

    public function getTestMerchantKey()
    {
        return $this->params->get('test_merchant_key', '');
    }

    /**
     * Get Live Merchant Key
     *
     * @return string
     * 
     * @since 1.0.0
     */

    public function getLiveMerchantKey()
    {
        return $this->params->get('live_merchant_key', '');
    }

    /**
     * Get Merchant Key based on payment environment
     *
     * @return string
     * 
     * @since 1.0.0
     */
    public function getMerchantKey()
    {
        return $this->getPaymentEnvironment() === 'test' ? self::getTestMerchantKey() : self::getLiveMerchantKey();
    }

    /**
     * Get URL based on payment environment
     *
     * @return string
     * 
     * @since 1.0.0
     */
    public function getUrl()
    {
        return $this->getPaymentEnvironment() === 'test' ? self::TEST_URL : self::LIVE_URL;
    }
}
